@@ -30,11 +30,9 @@ from kombu.utils.encoding import safe_str
 
 # dots are replaced by dash, all other punctuation
 # replaced by underscore.
-CHARS_REPLACE = string.punctuation.replace('-', '') \
-                                  .replace('_', '') \
-                                  .replace('.', '')
-CHARS_REPLACE_TABLE = string.maketrans(CHARS_REPLACE + '.',
-                                       "_" * len(CHARS_REPLACE) + '-')
+CHARS_REPLACE_TABLE = dict((ord(c), 0x5f)
+                           for c in string.punctuation if c not in '-_.')
+CHARS_REPLACE_TABLE[0x2e] = 0x2d  # '.' -> '-'
 
 
 class Table(Domain):
@@ -287,6 +285,9 @@ class Channel(virtual.Channel):
                    aws_secret_access_key=conninfo.password,
                    port=conninfo.port)
 
+    def _next_delivery_tag(self):
+        return uuid()  # See #73
+
     @property
     def sqs(self):
         if self._sqs is None:
