@@ -21,19 +21,26 @@ except:
     ctypes = None  # noqa
 
 
-class HashingDict(dict):
+def eqhash(o):
+    try:
+        return o.__eqhash__()
+    except AttributeError:
+        return hash(o)
+
+
+class EqualityDict(dict):
 
     def __getitem__(self, key):
-        h = hash(key)
+        h = eqhash(key)
         if h not in self:
             return self.__missing__(key)
         return dict.__getitem__(self, h)
 
     def __setitem__(self, key, value):
-        return dict.__setitem__(self, hash(key), value)
+        return dict.__setitem__(self, eqhash(key), value)
 
     def __delitem__(self, key):
-        return dict.__delitem__(self, hash(key))
+        return dict.__delitem__(self, eqhash(key))
 
 
 def say(m, *s):
@@ -51,7 +58,7 @@ def uuid4():
 
 def uuid():
     """Generate a unique id, having - hopefully - a very small chance of
-    collission.
+    collision.
 
     For now this is provided by :func:`uuid.uuid4`.
     """
@@ -65,7 +72,7 @@ if sys.version_info >= (3, 0):
         return kwargs
 else:
     def kwdict(kwargs):  # noqa
-        """Make sure keyword arguments are not in unicode.
+        """Make sure keyword arguments are not in Unicode.
 
         This should be fixed in newer Python versions,
         see: http://bugs.python.org/issue4978.
@@ -142,7 +149,7 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
         try:
             return fun(*args, **kwargs)
         except catch, exc:
-            if max_retries and retries > max_retries:
+            if max_retries is not None and retries > max_retries:
                 raise
             if errback:
                 errback(exc, interval)
